# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCommentInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message': 'str',
        'state': 'int',
        'element_occurrences': 'list[str]',
        'assembly_features': 'list[str]',
        'can_resolve_or_reopen': 'bool',
        'can_delete': 'bool',
        'user': 'BTUserSummaryInfo',
        'resolved_by': 'BTUserSummaryInfo',
        'resolved_at': 'datetime',
        'created_at': 'datetime',
        'view_data': 'BTViewDataInfo',
        'element_query': 'str',
        'element_feature': 'str',
        'assignee': 'BTUserSummaryInfo',
        'assigned_at': 'datetime',
        'top_level': 'bool',
        'reopened_by': 'BTUserSummaryInfo',
        'reopened_at': 'datetime',
        'workspace_id': 'str',
        'element_id': 'str',
        'document_id': 'str',
        'version_id': 'str',
        'attachment': 'BTCommentAttachmentInfo',
        'parent_id': 'str',
        'thumbnail': 'BTCommentAttachmentInfo',
        'release_package_id': 'str',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'message': 'message',
        'state': 'state',
        'element_occurrences': 'elementOccurrences',
        'assembly_features': 'assemblyFeatures',
        'can_resolve_or_reopen': 'canResolveOrReopen',
        'can_delete': 'canDelete',
        'user': 'user',
        'resolved_by': 'resolvedBy',
        'resolved_at': 'resolvedAt',
        'created_at': 'createdAt',
        'view_data': 'viewData',
        'element_query': 'elementQuery',
        'element_feature': 'elementFeature',
        'assignee': 'assignee',
        'assigned_at': 'assignedAt',
        'top_level': 'topLevel',
        'reopened_by': 'reopenedBy',
        'reopened_at': 'reopenedAt',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'document_id': 'documentId',
        'version_id': 'versionId',
        'attachment': 'attachment',
        'parent_id': 'parentId',
        'thumbnail': 'thumbnail',
        'release_package_id': 'releasePackageId',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, message=None, state=None, element_occurrences=None, assembly_features=None, can_resolve_or_reopen=None, can_delete=None, user=None, resolved_by=None, resolved_at=None, created_at=None, view_data=None, element_query=None, element_feature=None, assignee=None, assigned_at=None, top_level=None, reopened_by=None, reopened_at=None, workspace_id=None, element_id=None, document_id=None, version_id=None, attachment=None, parent_id=None, thumbnail=None, release_package_id=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTCommentInfo - a model defined in OpenAPI"""  # noqa: E501

        self._message = None
        self._state = None
        self._element_occurrences = None
        self._assembly_features = None
        self._can_resolve_or_reopen = None
        self._can_delete = None
        self._user = None
        self._resolved_by = None
        self._resolved_at = None
        self._created_at = None
        self._view_data = None
        self._element_query = None
        self._element_feature = None
        self._assignee = None
        self._assigned_at = None
        self._top_level = None
        self._reopened_by = None
        self._reopened_at = None
        self._workspace_id = None
        self._element_id = None
        self._document_id = None
        self._version_id = None
        self._attachment = None
        self._parent_id = None
        self._thumbnail = None
        self._release_package_id = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if state is not None:
            self.state = state
        if element_occurrences is not None:
            self.element_occurrences = element_occurrences
        if assembly_features is not None:
            self.assembly_features = assembly_features
        if can_resolve_or_reopen is not None:
            self.can_resolve_or_reopen = can_resolve_or_reopen
        if can_delete is not None:
            self.can_delete = can_delete
        if user is not None:
            self.user = user
        if resolved_by is not None:
            self.resolved_by = resolved_by
        if resolved_at is not None:
            self.resolved_at = resolved_at
        if created_at is not None:
            self.created_at = created_at
        if view_data is not None:
            self.view_data = view_data
        if element_query is not None:
            self.element_query = element_query
        if element_feature is not None:
            self.element_feature = element_feature
        if assignee is not None:
            self.assignee = assignee
        if assigned_at is not None:
            self.assigned_at = assigned_at
        if top_level is not None:
            self.top_level = top_level
        if reopened_by is not None:
            self.reopened_by = reopened_by
        if reopened_at is not None:
            self.reopened_at = reopened_at
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if document_id is not None:
            self.document_id = document_id
        if version_id is not None:
            self.version_id = version_id
        if attachment is not None:
            self.attachment = attachment
        if parent_id is not None:
            self.parent_id = parent_id
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if release_package_id is not None:
            self.release_package_id = release_package_id
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def message(self):
        """Gets the message of this BTCommentInfo.  # noqa: E501


        :return: The message of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BTCommentInfo.


        :param message: The message of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def state(self):
        """Gets the state of this BTCommentInfo.  # noqa: E501


        :return: The state of this BTCommentInfo.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTCommentInfo.


        :param state: The state of this BTCommentInfo.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def element_occurrences(self):
        """Gets the element_occurrences of this BTCommentInfo.  # noqa: E501


        :return: The element_occurrences of this BTCommentInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._element_occurrences

    @element_occurrences.setter
    def element_occurrences(self, element_occurrences):
        """Sets the element_occurrences of this BTCommentInfo.


        :param element_occurrences: The element_occurrences of this BTCommentInfo.  # noqa: E501
        :type: list[str]
        """

        self._element_occurrences = element_occurrences

    @property
    def assembly_features(self):
        """Gets the assembly_features of this BTCommentInfo.  # noqa: E501


        :return: The assembly_features of this BTCommentInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._assembly_features

    @assembly_features.setter
    def assembly_features(self, assembly_features):
        """Sets the assembly_features of this BTCommentInfo.


        :param assembly_features: The assembly_features of this BTCommentInfo.  # noqa: E501
        :type: list[str]
        """

        self._assembly_features = assembly_features

    @property
    def can_resolve_or_reopen(self):
        """Gets the can_resolve_or_reopen of this BTCommentInfo.  # noqa: E501


        :return: The can_resolve_or_reopen of this BTCommentInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_resolve_or_reopen

    @can_resolve_or_reopen.setter
    def can_resolve_or_reopen(self, can_resolve_or_reopen):
        """Sets the can_resolve_or_reopen of this BTCommentInfo.


        :param can_resolve_or_reopen: The can_resolve_or_reopen of this BTCommentInfo.  # noqa: E501
        :type: bool
        """

        self._can_resolve_or_reopen = can_resolve_or_reopen

    @property
    def can_delete(self):
        """Gets the can_delete of this BTCommentInfo.  # noqa: E501


        :return: The can_delete of this BTCommentInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete

    @can_delete.setter
    def can_delete(self, can_delete):
        """Sets the can_delete of this BTCommentInfo.


        :param can_delete: The can_delete of this BTCommentInfo.  # noqa: E501
        :type: bool
        """

        self._can_delete = can_delete

    @property
    def user(self):
        """Gets the user of this BTCommentInfo.  # noqa: E501


        :return: The user of this BTCommentInfo.  # noqa: E501
        :rtype: BTUserSummaryInfo
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this BTCommentInfo.


        :param user: The user of this BTCommentInfo.  # noqa: E501
        :type: BTUserSummaryInfo
        """

        self._user = user

    @property
    def resolved_by(self):
        """Gets the resolved_by of this BTCommentInfo.  # noqa: E501


        :return: The resolved_by of this BTCommentInfo.  # noqa: E501
        :rtype: BTUserSummaryInfo
        """
        return self._resolved_by

    @resolved_by.setter
    def resolved_by(self, resolved_by):
        """Sets the resolved_by of this BTCommentInfo.


        :param resolved_by: The resolved_by of this BTCommentInfo.  # noqa: E501
        :type: BTUserSummaryInfo
        """

        self._resolved_by = resolved_by

    @property
    def resolved_at(self):
        """Gets the resolved_at of this BTCommentInfo.  # noqa: E501


        :return: The resolved_at of this BTCommentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._resolved_at

    @resolved_at.setter
    def resolved_at(self, resolved_at):
        """Sets the resolved_at of this BTCommentInfo.


        :param resolved_at: The resolved_at of this BTCommentInfo.  # noqa: E501
        :type: datetime
        """

        self._resolved_at = resolved_at

    @property
    def created_at(self):
        """Gets the created_at of this BTCommentInfo.  # noqa: E501


        :return: The created_at of this BTCommentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTCommentInfo.


        :param created_at: The created_at of this BTCommentInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def view_data(self):
        """Gets the view_data of this BTCommentInfo.  # noqa: E501


        :return: The view_data of this BTCommentInfo.  # noqa: E501
        :rtype: BTViewDataInfo
        """
        return self._view_data

    @view_data.setter
    def view_data(self, view_data):
        """Sets the view_data of this BTCommentInfo.


        :param view_data: The view_data of this BTCommentInfo.  # noqa: E501
        :type: BTViewDataInfo
        """

        self._view_data = view_data

    @property
    def element_query(self):
        """Gets the element_query of this BTCommentInfo.  # noqa: E501


        :return: The element_query of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_query

    @element_query.setter
    def element_query(self, element_query):
        """Sets the element_query of this BTCommentInfo.


        :param element_query: The element_query of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._element_query = element_query

    @property
    def element_feature(self):
        """Gets the element_feature of this BTCommentInfo.  # noqa: E501


        :return: The element_feature of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_feature

    @element_feature.setter
    def element_feature(self, element_feature):
        """Sets the element_feature of this BTCommentInfo.


        :param element_feature: The element_feature of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._element_feature = element_feature

    @property
    def assignee(self):
        """Gets the assignee of this BTCommentInfo.  # noqa: E501


        :return: The assignee of this BTCommentInfo.  # noqa: E501
        :rtype: BTUserSummaryInfo
        """
        return self._assignee

    @assignee.setter
    def assignee(self, assignee):
        """Sets the assignee of this BTCommentInfo.


        :param assignee: The assignee of this BTCommentInfo.  # noqa: E501
        :type: BTUserSummaryInfo
        """

        self._assignee = assignee

    @property
    def assigned_at(self):
        """Gets the assigned_at of this BTCommentInfo.  # noqa: E501


        :return: The assigned_at of this BTCommentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._assigned_at

    @assigned_at.setter
    def assigned_at(self, assigned_at):
        """Sets the assigned_at of this BTCommentInfo.


        :param assigned_at: The assigned_at of this BTCommentInfo.  # noqa: E501
        :type: datetime
        """

        self._assigned_at = assigned_at

    @property
    def top_level(self):
        """Gets the top_level of this BTCommentInfo.  # noqa: E501


        :return: The top_level of this BTCommentInfo.  # noqa: E501
        :rtype: bool
        """
        return self._top_level

    @top_level.setter
    def top_level(self, top_level):
        """Sets the top_level of this BTCommentInfo.


        :param top_level: The top_level of this BTCommentInfo.  # noqa: E501
        :type: bool
        """

        self._top_level = top_level

    @property
    def reopened_by(self):
        """Gets the reopened_by of this BTCommentInfo.  # noqa: E501


        :return: The reopened_by of this BTCommentInfo.  # noqa: E501
        :rtype: BTUserSummaryInfo
        """
        return self._reopened_by

    @reopened_by.setter
    def reopened_by(self, reopened_by):
        """Sets the reopened_by of this BTCommentInfo.


        :param reopened_by: The reopened_by of this BTCommentInfo.  # noqa: E501
        :type: BTUserSummaryInfo
        """

        self._reopened_by = reopened_by

    @property
    def reopened_at(self):
        """Gets the reopened_at of this BTCommentInfo.  # noqa: E501


        :return: The reopened_at of this BTCommentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._reopened_at

    @reopened_at.setter
    def reopened_at(self, reopened_at):
        """Sets the reopened_at of this BTCommentInfo.


        :param reopened_at: The reopened_at of this BTCommentInfo.  # noqa: E501
        :type: datetime
        """

        self._reopened_at = reopened_at

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTCommentInfo.  # noqa: E501


        :return: The workspace_id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTCommentInfo.


        :param workspace_id: The workspace_id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTCommentInfo.  # noqa: E501


        :return: The element_id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTCommentInfo.


        :param element_id: The element_id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def document_id(self):
        """Gets the document_id of this BTCommentInfo.  # noqa: E501


        :return: The document_id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTCommentInfo.


        :param document_id: The document_id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def version_id(self):
        """Gets the version_id of this BTCommentInfo.  # noqa: E501


        :return: The version_id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTCommentInfo.


        :param version_id: The version_id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    @property
    def attachment(self):
        """Gets the attachment of this BTCommentInfo.  # noqa: E501


        :return: The attachment of this BTCommentInfo.  # noqa: E501
        :rtype: BTCommentAttachmentInfo
        """
        return self._attachment

    @attachment.setter
    def attachment(self, attachment):
        """Sets the attachment of this BTCommentInfo.


        :param attachment: The attachment of this BTCommentInfo.  # noqa: E501
        :type: BTCommentAttachmentInfo
        """

        self._attachment = attachment

    @property
    def parent_id(self):
        """Gets the parent_id of this BTCommentInfo.  # noqa: E501


        :return: The parent_id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTCommentInfo.


        :param parent_id: The parent_id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def thumbnail(self):
        """Gets the thumbnail of this BTCommentInfo.  # noqa: E501


        :return: The thumbnail of this BTCommentInfo.  # noqa: E501
        :rtype: BTCommentAttachmentInfo
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this BTCommentInfo.


        :param thumbnail: The thumbnail of this BTCommentInfo.  # noqa: E501
        :type: BTCommentAttachmentInfo
        """

        self._thumbnail = thumbnail

    @property
    def release_package_id(self):
        """Gets the release_package_id of this BTCommentInfo.  # noqa: E501


        :return: The release_package_id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._release_package_id

    @release_package_id.setter
    def release_package_id(self, release_package_id):
        """Sets the release_package_id of this BTCommentInfo.


        :param release_package_id: The release_package_id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._release_package_id = release_package_id

    @property
    def name(self):
        """Gets the name of this BTCommentInfo.  # noqa: E501


        :return: The name of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTCommentInfo.


        :param name: The name of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTCommentInfo.  # noqa: E501


        :return: The id of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTCommentInfo.


        :param id: The id of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTCommentInfo.  # noqa: E501


        :return: The href of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTCommentInfo.


        :param href: The href of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTCommentInfo.  # noqa: E501


        :return: The view_ref of this BTCommentInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTCommentInfo.


        :param view_ref: The view_ref of this BTCommentInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCommentInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTStandardContentCustomParameterDefinitionId(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'property_id': 'str',
        'owner_id': 'str',
        'owner_type': 'int',
        'parameter_name': 'str',
        'standard': 'str',
        'category': 'str',
        'types': 'str',
        'type': 'str'
    }

    attribute_map = {
        'property_id': 'propertyId',
        'owner_id': 'ownerId',
        'owner_type': 'ownerType',
        'parameter_name': 'parameterName',
        'standard': 'standard',
        'category': 'category',
        'types': 'types',
        'type': 'type'
    }

    def __init__(self, property_id=None, owner_id=None, owner_type=None, parameter_name=None, standard=None, category=None, types=None, type=None):  # noqa: E501
        """BTStandardContentCustomParameterDefinitionId - a model defined in OpenAPI"""  # noqa: E501

        self._property_id = None
        self._owner_id = None
        self._owner_type = None
        self._parameter_name = None
        self._standard = None
        self._category = None
        self._types = None
        self._type = None
        self.discriminator = None

        if property_id is not None:
            self.property_id = property_id
        if owner_id is not None:
            self.owner_id = owner_id
        if owner_type is not None:
            self.owner_type = owner_type
        if parameter_name is not None:
            self.parameter_name = parameter_name
        if standard is not None:
            self.standard = standard
        if category is not None:
            self.category = category
        if types is not None:
            self.types = types
        if type is not None:
            self.type = type

    @property
    def property_id(self):
        """Gets the property_id of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The property_id of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._property_id

    @property_id.setter
    def property_id(self, property_id):
        """Sets the property_id of this BTStandardContentCustomParameterDefinitionId.


        :param property_id: The property_id of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._property_id = property_id

    @property
    def owner_id(self):
        """Gets the owner_id of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The owner_id of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTStandardContentCustomParameterDefinitionId.


        :param owner_id: The owner_id of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def owner_type(self):
        """Gets the owner_type of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The owner_type of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: int
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this BTStandardContentCustomParameterDefinitionId.


        :param owner_type: The owner_type of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: int
        """

        self._owner_type = owner_type

    @property
    def parameter_name(self):
        """Gets the parameter_name of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The parameter_name of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._parameter_name

    @parameter_name.setter
    def parameter_name(self, parameter_name):
        """Sets the parameter_name of this BTStandardContentCustomParameterDefinitionId.


        :param parameter_name: The parameter_name of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._parameter_name = parameter_name

    @property
    def standard(self):
        """Gets the standard of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The standard of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this BTStandardContentCustomParameterDefinitionId.


        :param standard: The standard of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._standard = standard

    @property
    def category(self):
        """Gets the category of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The category of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this BTStandardContentCustomParameterDefinitionId.


        :param category: The category of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def types(self):
        """Gets the types of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The types of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._types

    @types.setter
    def types(self, types):
        """Sets the types of this BTStandardContentCustomParameterDefinitionId.


        :param types: The types of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._types = types

    @property
    def type(self):
        """Gets the type of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501


        :return: The type of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTStandardContentCustomParameterDefinitionId.


        :param type: The type of this BTStandardContentCustomParameterDefinitionId.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTStandardContentCustomParameterDefinitionId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCompanyNoPublicDocumentParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'no_public_documents': 'bool'
    }

    attribute_map = {
        'no_public_documents': 'noPublicDocuments'
    }

    def __init__(self, no_public_documents=None):  # noqa: E501
        """BTCompanyNoPublicDocumentParams - a model defined in OpenAPI"""  # noqa: E501

        self._no_public_documents = None
        self.discriminator = None

        if no_public_documents is not None:
            self.no_public_documents = no_public_documents

    @property
    def no_public_documents(self):
        """Gets the no_public_documents of this BTCompanyNoPublicDocumentParams.  # noqa: E501


        :return: The no_public_documents of this BTCompanyNoPublicDocumentParams.  # noqa: E501
        :rtype: bool
        """
        return self._no_public_documents

    @no_public_documents.setter
    def no_public_documents(self, no_public_documents):
        """Sets the no_public_documents of this BTCompanyNoPublicDocumentParams.


        :param no_public_documents: The no_public_documents of this BTCompanyNoPublicDocumentParams.  # noqa: E501
        :type: bool
        """

        self._no_public_documents = no_public_documents

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCompanyNoPublicDocumentParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPartMetadataInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'state': 'str',
        'href': 'str',
        'description': 'str',
        'project': 'str',
        'vendor': 'str',
        'title1': 'str',
        'revision': 'str',
        'title2': 'str',
        'title3': 'str',
        'microversion_id': 'str',
        'part_number': 'str',
        'product_line': 'str',
        'thumbnail_info': 'BTThumbnailInfo',
        'element_id': 'str',
        'part_query': 'str',
        'part_id': 'str',
        'unflattened_part_id': 'str',
        'configuration_id': 'str',
        'appearance': 'BTPartAppearanceInfo',
        'material': 'BTPartMaterialInfo',
        'thumbnail_configuration_id': 'str',
        'custom_properties': 'dict(str, str)',
        'custom_property_definitions': 'dict(str, BTCustomPropertyDefinitionInfo)',
        'body_type': 'str',
        'is_mesh': 'bool',
        'referencing_configured_part_node_ids': 'list[str]',
        'is_flattened_body': 'bool',
        'is_hidden': 'bool',
        'ordinal': 'int',
        'property_source_types': 'dict(str, int)'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'state': 'state',
        'href': 'href',
        'description': 'description',
        'project': 'project',
        'vendor': 'vendor',
        'title1': 'title1',
        'revision': 'revision',
        'title2': 'title2',
        'title3': 'title3',
        'microversion_id': 'microversionId',
        'part_number': 'partNumber',
        'product_line': 'productLine',
        'thumbnail_info': 'thumbnailInfo',
        'element_id': 'elementId',
        'part_query': 'partQuery',
        'part_id': 'partId',
        'unflattened_part_id': 'unflattenedPartId',
        'configuration_id': 'configurationId',
        'appearance': 'appearance',
        'material': 'material',
        'thumbnail_configuration_id': 'thumbnailConfigurationId',
        'custom_properties': 'customProperties',
        'custom_property_definitions': 'customPropertyDefinitions',
        'body_type': 'bodyType',
        'is_mesh': 'isMesh',
        'referencing_configured_part_node_ids': 'referencingConfiguredPartNodeIds',
        'is_flattened_body': 'isFlattenedBody',
        'is_hidden': 'isHidden',
        'ordinal': 'ordinal',
        'property_source_types': 'propertySourceTypes'
    }

    def __init__(self, name=None, id=None, state=None, href=None, description=None, project=None, vendor=None, title1=None, revision=None, title2=None, title3=None, microversion_id=None, part_number=None, product_line=None, thumbnail_info=None, element_id=None, part_query=None, part_id=None, unflattened_part_id=None, configuration_id=None, appearance=None, material=None, thumbnail_configuration_id=None, custom_properties=None, custom_property_definitions=None, body_type=None, is_mesh=None, referencing_configured_part_node_ids=None, is_flattened_body=None, is_hidden=None, ordinal=None, property_source_types=None):  # noqa: E501
        """BTPartMetadataInfo - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._id = None
        self._state = None
        self._href = None
        self._description = None
        self._project = None
        self._vendor = None
        self._title1 = None
        self._revision = None
        self._title2 = None
        self._title3 = None
        self._microversion_id = None
        self._part_number = None
        self._product_line = None
        self._thumbnail_info = None
        self._element_id = None
        self._part_query = None
        self._part_id = None
        self._unflattened_part_id = None
        self._configuration_id = None
        self._appearance = None
        self._material = None
        self._thumbnail_configuration_id = None
        self._custom_properties = None
        self._custom_property_definitions = None
        self._body_type = None
        self._is_mesh = None
        self._referencing_configured_part_node_ids = None
        self._is_flattened_body = None
        self._is_hidden = None
        self._ordinal = None
        self._property_source_types = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if state is not None:
            self.state = state
        if href is not None:
            self.href = href
        if description is not None:
            self.description = description
        if project is not None:
            self.project = project
        if vendor is not None:
            self.vendor = vendor
        if title1 is not None:
            self.title1 = title1
        if revision is not None:
            self.revision = revision
        if title2 is not None:
            self.title2 = title2
        if title3 is not None:
            self.title3 = title3
        if microversion_id is not None:
            self.microversion_id = microversion_id
        if part_number is not None:
            self.part_number = part_number
        if product_line is not None:
            self.product_line = product_line
        if thumbnail_info is not None:
            self.thumbnail_info = thumbnail_info
        if element_id is not None:
            self.element_id = element_id
        if part_query is not None:
            self.part_query = part_query
        if part_id is not None:
            self.part_id = part_id
        if unflattened_part_id is not None:
            self.unflattened_part_id = unflattened_part_id
        if configuration_id is not None:
            self.configuration_id = configuration_id
        if appearance is not None:
            self.appearance = appearance
        if material is not None:
            self.material = material
        if thumbnail_configuration_id is not None:
            self.thumbnail_configuration_id = thumbnail_configuration_id
        if custom_properties is not None:
            self.custom_properties = custom_properties
        if custom_property_definitions is not None:
            self.custom_property_definitions = custom_property_definitions
        if body_type is not None:
            self.body_type = body_type
        if is_mesh is not None:
            self.is_mesh = is_mesh
        if referencing_configured_part_node_ids is not None:
            self.referencing_configured_part_node_ids = referencing_configured_part_node_ids
        if is_flattened_body is not None:
            self.is_flattened_body = is_flattened_body
        if is_hidden is not None:
            self.is_hidden = is_hidden
        if ordinal is not None:
            self.ordinal = ordinal
        if property_source_types is not None:
            self.property_source_types = property_source_types

    @property
    def name(self):
        """Gets the name of this BTPartMetadataInfo.  # noqa: E501


        :return: The name of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTPartMetadataInfo.


        :param name: The name of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTPartMetadataInfo.  # noqa: E501


        :return: The id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTPartMetadataInfo.


        :param id: The id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def state(self):
        """Gets the state of this BTPartMetadataInfo.  # noqa: E501


        :return: The state of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTPartMetadataInfo.


        :param state: The state of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "PENDING", "RELEASED", "OBSOLETE", "REJECTED", "DISCARDED"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def href(self):
        """Gets the href of this BTPartMetadataInfo.  # noqa: E501


        :return: The href of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTPartMetadataInfo.


        :param href: The href of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def description(self):
        """Gets the description of this BTPartMetadataInfo.  # noqa: E501


        :return: The description of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTPartMetadataInfo.


        :param description: The description of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def project(self):
        """Gets the project of this BTPartMetadataInfo.  # noqa: E501


        :return: The project of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this BTPartMetadataInfo.


        :param project: The project of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._project = project

    @property
    def vendor(self):
        """Gets the vendor of this BTPartMetadataInfo.  # noqa: E501


        :return: The vendor of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this BTPartMetadataInfo.


        :param vendor: The vendor of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def title1(self):
        """Gets the title1 of this BTPartMetadataInfo.  # noqa: E501


        :return: The title1 of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._title1

    @title1.setter
    def title1(self, title1):
        """Sets the title1 of this BTPartMetadataInfo.


        :param title1: The title1 of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._title1 = title1

    @property
    def revision(self):
        """Gets the revision of this BTPartMetadataInfo.  # noqa: E501


        :return: The revision of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this BTPartMetadataInfo.


        :param revision: The revision of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def title2(self):
        """Gets the title2 of this BTPartMetadataInfo.  # noqa: E501


        :return: The title2 of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._title2

    @title2.setter
    def title2(self, title2):
        """Sets the title2 of this BTPartMetadataInfo.


        :param title2: The title2 of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._title2 = title2

    @property
    def title3(self):
        """Gets the title3 of this BTPartMetadataInfo.  # noqa: E501


        :return: The title3 of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._title3

    @title3.setter
    def title3(self, title3):
        """Sets the title3 of this BTPartMetadataInfo.


        :param title3: The title3 of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._title3 = title3

    @property
    def microversion_id(self):
        """Gets the microversion_id of this BTPartMetadataInfo.  # noqa: E501


        :return: The microversion_id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._microversion_id

    @microversion_id.setter
    def microversion_id(self, microversion_id):
        """Sets the microversion_id of this BTPartMetadataInfo.


        :param microversion_id: The microversion_id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._microversion_id = microversion_id

    @property
    def part_number(self):
        """Gets the part_number of this BTPartMetadataInfo.  # noqa: E501


        :return: The part_number of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this BTPartMetadataInfo.


        :param part_number: The part_number of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def product_line(self):
        """Gets the product_line of this BTPartMetadataInfo.  # noqa: E501


        :return: The product_line of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this BTPartMetadataInfo.


        :param product_line: The product_line of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def thumbnail_info(self):
        """Gets the thumbnail_info of this BTPartMetadataInfo.  # noqa: E501


        :return: The thumbnail_info of this BTPartMetadataInfo.  # noqa: E501
        :rtype: BTThumbnailInfo
        """
        return self._thumbnail_info

    @thumbnail_info.setter
    def thumbnail_info(self, thumbnail_info):
        """Sets the thumbnail_info of this BTPartMetadataInfo.


        :param thumbnail_info: The thumbnail_info of this BTPartMetadataInfo.  # noqa: E501
        :type: BTThumbnailInfo
        """

        self._thumbnail_info = thumbnail_info

    @property
    def element_id(self):
        """Gets the element_id of this BTPartMetadataInfo.  # noqa: E501


        :return: The element_id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTPartMetadataInfo.


        :param element_id: The element_id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def part_query(self):
        """Gets the part_query of this BTPartMetadataInfo.  # noqa: E501


        :return: The part_query of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._part_query

    @part_query.setter
    def part_query(self, part_query):
        """Sets the part_query of this BTPartMetadataInfo.


        :param part_query: The part_query of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._part_query = part_query

    @property
    def part_id(self):
        """Gets the part_id of this BTPartMetadataInfo.  # noqa: E501


        :return: The part_id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTPartMetadataInfo.


        :param part_id: The part_id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def unflattened_part_id(self):
        """Gets the unflattened_part_id of this BTPartMetadataInfo.  # noqa: E501


        :return: The unflattened_part_id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._unflattened_part_id

    @unflattened_part_id.setter
    def unflattened_part_id(self, unflattened_part_id):
        """Sets the unflattened_part_id of this BTPartMetadataInfo.


        :param unflattened_part_id: The unflattened_part_id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._unflattened_part_id = unflattened_part_id

    @property
    def configuration_id(self):
        """Gets the configuration_id of this BTPartMetadataInfo.  # noqa: E501


        :return: The configuration_id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._configuration_id

    @configuration_id.setter
    def configuration_id(self, configuration_id):
        """Sets the configuration_id of this BTPartMetadataInfo.


        :param configuration_id: The configuration_id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._configuration_id = configuration_id

    @property
    def appearance(self):
        """Gets the appearance of this BTPartMetadataInfo.  # noqa: E501


        :return: The appearance of this BTPartMetadataInfo.  # noqa: E501
        :rtype: BTPartAppearanceInfo
        """
        return self._appearance

    @appearance.setter
    def appearance(self, appearance):
        """Sets the appearance of this BTPartMetadataInfo.


        :param appearance: The appearance of this BTPartMetadataInfo.  # noqa: E501
        :type: BTPartAppearanceInfo
        """

        self._appearance = appearance

    @property
    def material(self):
        """Gets the material of this BTPartMetadataInfo.  # noqa: E501


        :return: The material of this BTPartMetadataInfo.  # noqa: E501
        :rtype: BTPartMaterialInfo
        """
        return self._material

    @material.setter
    def material(self, material):
        """Sets the material of this BTPartMetadataInfo.


        :param material: The material of this BTPartMetadataInfo.  # noqa: E501
        :type: BTPartMaterialInfo
        """

        self._material = material

    @property
    def thumbnail_configuration_id(self):
        """Gets the thumbnail_configuration_id of this BTPartMetadataInfo.  # noqa: E501


        :return: The thumbnail_configuration_id of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_configuration_id

    @thumbnail_configuration_id.setter
    def thumbnail_configuration_id(self, thumbnail_configuration_id):
        """Sets the thumbnail_configuration_id of this BTPartMetadataInfo.


        :param thumbnail_configuration_id: The thumbnail_configuration_id of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._thumbnail_configuration_id = thumbnail_configuration_id

    @property
    def custom_properties(self):
        """Gets the custom_properties of this BTPartMetadataInfo.  # noqa: E501


        :return: The custom_properties of this BTPartMetadataInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """Sets the custom_properties of this BTPartMetadataInfo.


        :param custom_properties: The custom_properties of this BTPartMetadataInfo.  # noqa: E501
        :type: dict(str, str)
        """

        self._custom_properties = custom_properties

    @property
    def custom_property_definitions(self):
        """Gets the custom_property_definitions of this BTPartMetadataInfo.  # noqa: E501


        :return: The custom_property_definitions of this BTPartMetadataInfo.  # noqa: E501
        :rtype: dict(str, BTCustomPropertyDefinitionInfo)
        """
        return self._custom_property_definitions

    @custom_property_definitions.setter
    def custom_property_definitions(self, custom_property_definitions):
        """Sets the custom_property_definitions of this BTPartMetadataInfo.


        :param custom_property_definitions: The custom_property_definitions of this BTPartMetadataInfo.  # noqa: E501
        :type: dict(str, BTCustomPropertyDefinitionInfo)
        """

        self._custom_property_definitions = custom_property_definitions

    @property
    def body_type(self):
        """Gets the body_type of this BTPartMetadataInfo.  # noqa: E501


        :return: The body_type of this BTPartMetadataInfo.  # noqa: E501
        :rtype: str
        """
        return self._body_type

    @body_type.setter
    def body_type(self, body_type):
        """Sets the body_type of this BTPartMetadataInfo.


        :param body_type: The body_type of this BTPartMetadataInfo.  # noqa: E501
        :type: str
        """

        self._body_type = body_type

    @property
    def is_mesh(self):
        """Gets the is_mesh of this BTPartMetadataInfo.  # noqa: E501


        :return: The is_mesh of this BTPartMetadataInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_mesh

    @is_mesh.setter
    def is_mesh(self, is_mesh):
        """Sets the is_mesh of this BTPartMetadataInfo.


        :param is_mesh: The is_mesh of this BTPartMetadataInfo.  # noqa: E501
        :type: bool
        """

        self._is_mesh = is_mesh

    @property
    def referencing_configured_part_node_ids(self):
        """Gets the referencing_configured_part_node_ids of this BTPartMetadataInfo.  # noqa: E501


        :return: The referencing_configured_part_node_ids of this BTPartMetadataInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._referencing_configured_part_node_ids

    @referencing_configured_part_node_ids.setter
    def referencing_configured_part_node_ids(self, referencing_configured_part_node_ids):
        """Sets the referencing_configured_part_node_ids of this BTPartMetadataInfo.


        :param referencing_configured_part_node_ids: The referencing_configured_part_node_ids of this BTPartMetadataInfo.  # noqa: E501
        :type: list[str]
        """

        self._referencing_configured_part_node_ids = referencing_configured_part_node_ids

    @property
    def is_flattened_body(self):
        """Gets the is_flattened_body of this BTPartMetadataInfo.  # noqa: E501


        :return: The is_flattened_body of this BTPartMetadataInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_flattened_body

    @is_flattened_body.setter
    def is_flattened_body(self, is_flattened_body):
        """Sets the is_flattened_body of this BTPartMetadataInfo.


        :param is_flattened_body: The is_flattened_body of this BTPartMetadataInfo.  # noqa: E501
        :type: bool
        """

        self._is_flattened_body = is_flattened_body

    @property
    def is_hidden(self):
        """Gets the is_hidden of this BTPartMetadataInfo.  # noqa: E501


        :return: The is_hidden of this BTPartMetadataInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this BTPartMetadataInfo.


        :param is_hidden: The is_hidden of this BTPartMetadataInfo.  # noqa: E501
        :type: bool
        """

        self._is_hidden = is_hidden

    @property
    def ordinal(self):
        """Gets the ordinal of this BTPartMetadataInfo.  # noqa: E501


        :return: The ordinal of this BTPartMetadataInfo.  # noqa: E501
        :rtype: int
        """
        return self._ordinal

    @ordinal.setter
    def ordinal(self, ordinal):
        """Sets the ordinal of this BTPartMetadataInfo.


        :param ordinal: The ordinal of this BTPartMetadataInfo.  # noqa: E501
        :type: int
        """

        self._ordinal = ordinal

    @property
    def property_source_types(self):
        """Gets the property_source_types of this BTPartMetadataInfo.  # noqa: E501


        :return: The property_source_types of this BTPartMetadataInfo.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._property_source_types

    @property_source_types.setter
    def property_source_types(self, property_source_types):
        """Sets the property_source_types of this BTPartMetadataInfo.


        :param property_source_types: The property_source_types of this BTPartMetadataInfo.  # noqa: E501
        :type: dict(str, int)
        """

        self._property_source_types = property_source_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPartMetadataInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class JsonNode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'array': 'bool',
        'null': 'bool',
        'float': 'bool',
        'object': 'bool',
        'node_type': 'str',
        'textual': 'bool',
        'value_node': 'bool',
        'container_node': 'bool',
        'missing_node': 'bool',
        'pojo': 'bool',
        'number': 'bool',
        'integral_number': 'bool',
        'floating_point_number': 'bool',
        'short': 'bool',
        'int': 'bool',
        'long': 'bool',
        'double': 'bool',
        'big_decimal': 'bool',
        'big_integer': 'bool',
        'boolean': 'bool',
        'binary': 'bool'
    }

    attribute_map = {
        'array': 'array',
        'null': 'null',
        'float': 'float',
        'object': 'object',
        'node_type': 'nodeType',
        'textual': 'textual',
        'value_node': 'valueNode',
        'container_node': 'containerNode',
        'missing_node': 'missingNode',
        'pojo': 'pojo',
        'number': 'number',
        'integral_number': 'integralNumber',
        'floating_point_number': 'floatingPointNumber',
        'short': 'short',
        'int': 'int',
        'long': 'long',
        'double': 'double',
        'big_decimal': 'bigDecimal',
        'big_integer': 'bigInteger',
        'boolean': 'boolean',
        'binary': 'binary'
    }

    def __init__(self, array=None, null=None, float=None, object=None, node_type=None, textual=None, value_node=None, container_node=None, missing_node=None, pojo=None, number=None, integral_number=None, floating_point_number=None, short=None, int=None, long=None, double=None, big_decimal=None, big_integer=None, boolean=None, binary=None):  # noqa: E501
        """JsonNode - a model defined in OpenAPI"""  # noqa: E501

        self._array = None
        self._null = None
        self._float = None
        self._object = None
        self._node_type = None
        self._textual = None
        self._value_node = None
        self._container_node = None
        self._missing_node = None
        self._pojo = None
        self._number = None
        self._integral_number = None
        self._floating_point_number = None
        self._short = None
        self._int = None
        self._long = None
        self._double = None
        self._big_decimal = None
        self._big_integer = None
        self._boolean = None
        self._binary = None
        self.discriminator = None

        if array is not None:
            self.array = array
        if null is not None:
            self.null = null
        if float is not None:
            self.float = float
        if object is not None:
            self.object = object
        if node_type is not None:
            self.node_type = node_type
        if textual is not None:
            self.textual = textual
        if value_node is not None:
            self.value_node = value_node
        if container_node is not None:
            self.container_node = container_node
        if missing_node is not None:
            self.missing_node = missing_node
        if pojo is not None:
            self.pojo = pojo
        if number is not None:
            self.number = number
        if integral_number is not None:
            self.integral_number = integral_number
        if floating_point_number is not None:
            self.floating_point_number = floating_point_number
        if short is not None:
            self.short = short
        if int is not None:
            self.int = int
        if long is not None:
            self.long = long
        if double is not None:
            self.double = double
        if big_decimal is not None:
            self.big_decimal = big_decimal
        if big_integer is not None:
            self.big_integer = big_integer
        if boolean is not None:
            self.boolean = boolean
        if binary is not None:
            self.binary = binary

    @property
    def array(self):
        """Gets the array of this JsonNode.  # noqa: E501


        :return: The array of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._array

    @array.setter
    def array(self, array):
        """Sets the array of this JsonNode.


        :param array: The array of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._array = array

    @property
    def null(self):
        """Gets the null of this JsonNode.  # noqa: E501


        :return: The null of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._null

    @null.setter
    def null(self, null):
        """Sets the null of this JsonNode.


        :param null: The null of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._null = null

    @property
    def float(self):
        """Gets the float of this JsonNode.  # noqa: E501


        :return: The float of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._float

    @float.setter
    def float(self, float):
        """Sets the float of this JsonNode.


        :param float: The float of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._float = float

    @property
    def object(self):
        """Gets the object of this JsonNode.  # noqa: E501


        :return: The object of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this JsonNode.


        :param object: The object of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._object = object

    @property
    def node_type(self):
        """Gets the node_type of this JsonNode.  # noqa: E501


        :return: The node_type of this JsonNode.  # noqa: E501
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this JsonNode.


        :param node_type: The node_type of this JsonNode.  # noqa: E501
        :type: str
        """
        allowed_values = ["ARRAY", "BINARY", "BOOLEAN", "MISSING", "NULL", "NUMBER", "OBJECT", "POJO", "STRING"]  # noqa: E501
        if node_type not in allowed_values:
            raise ValueError(
                "Invalid value for `node_type` ({0}), must be one of {1}"  # noqa: E501
                .format(node_type, allowed_values)
            )

        self._node_type = node_type

    @property
    def textual(self):
        """Gets the textual of this JsonNode.  # noqa: E501


        :return: The textual of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._textual

    @textual.setter
    def textual(self, textual):
        """Sets the textual of this JsonNode.


        :param textual: The textual of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._textual = textual

    @property
    def value_node(self):
        """Gets the value_node of this JsonNode.  # noqa: E501


        :return: The value_node of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._value_node

    @value_node.setter
    def value_node(self, value_node):
        """Sets the value_node of this JsonNode.


        :param value_node: The value_node of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._value_node = value_node

    @property
    def container_node(self):
        """Gets the container_node of this JsonNode.  # noqa: E501


        :return: The container_node of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._container_node

    @container_node.setter
    def container_node(self, container_node):
        """Sets the container_node of this JsonNode.


        :param container_node: The container_node of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._container_node = container_node

    @property
    def missing_node(self):
        """Gets the missing_node of this JsonNode.  # noqa: E501


        :return: The missing_node of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._missing_node

    @missing_node.setter
    def missing_node(self, missing_node):
        """Sets the missing_node of this JsonNode.


        :param missing_node: The missing_node of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._missing_node = missing_node

    @property
    def pojo(self):
        """Gets the pojo of this JsonNode.  # noqa: E501


        :return: The pojo of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._pojo

    @pojo.setter
    def pojo(self, pojo):
        """Sets the pojo of this JsonNode.


        :param pojo: The pojo of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._pojo = pojo

    @property
    def number(self):
        """Gets the number of this JsonNode.  # noqa: E501


        :return: The number of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this JsonNode.


        :param number: The number of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._number = number

    @property
    def integral_number(self):
        """Gets the integral_number of this JsonNode.  # noqa: E501


        :return: The integral_number of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._integral_number

    @integral_number.setter
    def integral_number(self, integral_number):
        """Sets the integral_number of this JsonNode.


        :param integral_number: The integral_number of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._integral_number = integral_number

    @property
    def floating_point_number(self):
        """Gets the floating_point_number of this JsonNode.  # noqa: E501


        :return: The floating_point_number of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._floating_point_number

    @floating_point_number.setter
    def floating_point_number(self, floating_point_number):
        """Sets the floating_point_number of this JsonNode.


        :param floating_point_number: The floating_point_number of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._floating_point_number = floating_point_number

    @property
    def short(self):
        """Gets the short of this JsonNode.  # noqa: E501


        :return: The short of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._short

    @short.setter
    def short(self, short):
        """Sets the short of this JsonNode.


        :param short: The short of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._short = short

    @property
    def int(self):
        """Gets the int of this JsonNode.  # noqa: E501


        :return: The int of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._int

    @int.setter
    def int(self, int):
        """Sets the int of this JsonNode.


        :param int: The int of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._int = int

    @property
    def long(self):
        """Gets the long of this JsonNode.  # noqa: E501


        :return: The long of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._long

    @long.setter
    def long(self, long):
        """Sets the long of this JsonNode.


        :param long: The long of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._long = long

    @property
    def double(self):
        """Gets the double of this JsonNode.  # noqa: E501


        :return: The double of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._double

    @double.setter
    def double(self, double):
        """Sets the double of this JsonNode.


        :param double: The double of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._double = double

    @property
    def big_decimal(self):
        """Gets the big_decimal of this JsonNode.  # noqa: E501


        :return: The big_decimal of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._big_decimal

    @big_decimal.setter
    def big_decimal(self, big_decimal):
        """Sets the big_decimal of this JsonNode.


        :param big_decimal: The big_decimal of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._big_decimal = big_decimal

    @property
    def big_integer(self):
        """Gets the big_integer of this JsonNode.  # noqa: E501


        :return: The big_integer of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._big_integer

    @big_integer.setter
    def big_integer(self, big_integer):
        """Sets the big_integer of this JsonNode.


        :param big_integer: The big_integer of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._big_integer = big_integer

    @property
    def boolean(self):
        """Gets the boolean of this JsonNode.  # noqa: E501


        :return: The boolean of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._boolean

    @boolean.setter
    def boolean(self, boolean):
        """Sets the boolean of this JsonNode.


        :param boolean: The boolean of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._boolean = boolean

    @property
    def binary(self):
        """Gets the binary of this JsonNode.  # noqa: E501


        :return: The binary of this JsonNode.  # noqa: E501
        :rtype: bool
        """
        return self._binary

    @binary.setter
    def binary(self, binary):
        """Sets the binary of this JsonNode.


        :param binary: The binary of this JsonNode.  # noqa: E501
        :type: bool
        """

        self._binary = binary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JsonNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTTranslateFormatParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'link_document_id': 'str',
        'configuration': 'str',
        'element_id': 'str',
        'link_document_workspace_id': 'str',
        'cloud_object_id': 'str',
        'part_ids': 'str',
        'trigger_auto_download': 'bool',
        'from_user_id': 'str',
        'cloud_storage_account_id': 'str',
        'connection_id': 'str',
        'email_attachment': 'bool',
        'email_link': 'bool',
        'email_subject': 'str',
        'email_message': 'str',
        'email_to': 'list[str]',
        'send_copy_to_me': 'bool',
        'format_name': 'str',
        'notify_user': 'bool',
        'store_in_document': 'bool',
        'version_string': 'str',
        'source_name': 'str',
        'destination_name': 'str',
        'flatten': 'bool',
        'include_export_ids': 'bool',
        'text_as_geometry': 'bool',
        'show_overridden_dimensions': 'bool',
        'current_sheet_only': 'bool',
        'image_width': 'int',
        'image_height': 'int',
        'color_method': 'str',
        'splines_as_polylines': 'bool',
        'selectable_pdf_text': 'bool',
        'grouping': 'bool',
        'import_in_background': 'bool',
        'unit': 'str',
        'split_assemblies_into_multiple_documents': 'bool',
        'flatten_assemblies': 'bool',
        'gety_axis_is_up': 'bool',
        'allow_faulty_parts': 'bool',
        'project_id': 'str',
        'parent_id': 'str',
        'foreign_id': 'str',
        'upload_id': 'str',
        'original_foreign_id': 'str',
        'import_within_document': 'bool',
        'blob_element_id': 'str',
        'blob_microversion_id': 'str',
        'specify_units': 'bool'
    }

    attribute_map = {
        'link_document_id': 'linkDocumentId',
        'configuration': 'configuration',
        'element_id': 'elementId',
        'link_document_workspace_id': 'linkDocumentWorkspaceId',
        'cloud_object_id': 'cloudObjectId',
        'part_ids': 'partIds',
        'trigger_auto_download': 'triggerAutoDownload',
        'from_user_id': 'fromUserId',
        'cloud_storage_account_id': 'cloudStorageAccountId',
        'connection_id': 'connectionId',
        'email_attachment': 'emailAttachment',
        'email_link': 'emailLink',
        'email_subject': 'emailSubject',
        'email_message': 'emailMessage',
        'email_to': 'emailTo',
        'send_copy_to_me': 'sendCopyToMe',
        'format_name': 'formatName',
        'notify_user': 'notifyUser',
        'store_in_document': 'storeInDocument',
        'version_string': 'versionString',
        'source_name': 'sourceName',
        'destination_name': 'destinationName',
        'flatten': 'flatten',
        'include_export_ids': 'includeExportIds',
        'text_as_geometry': 'textAsGeometry',
        'show_overridden_dimensions': 'showOverriddenDimensions',
        'current_sheet_only': 'currentSheetOnly',
        'image_width': 'imageWidth',
        'image_height': 'imageHeight',
        'color_method': 'colorMethod',
        'splines_as_polylines': 'splinesAsPolylines',
        'selectable_pdf_text': 'selectablePdfText',
        'grouping': 'grouping',
        'import_in_background': 'importInBackground',
        'unit': 'unit',
        'split_assemblies_into_multiple_documents': 'splitAssembliesIntoMultipleDocuments',
        'flatten_assemblies': 'flattenAssemblies',
        'gety_axis_is_up': 'getyAxisIsUp',
        'allow_faulty_parts': 'allowFaultyParts',
        'project_id': 'projectId',
        'parent_id': 'parentId',
        'foreign_id': 'foreignId',
        'upload_id': 'uploadId',
        'original_foreign_id': 'originalForeignId',
        'import_within_document': 'importWithinDocument',
        'blob_element_id': 'blobElementId',
        'blob_microversion_id': 'blobMicroversionId',
        'specify_units': 'specifyUnits'
    }

    def __init__(self, link_document_id=None, configuration=None, element_id=None, link_document_workspace_id=None, cloud_object_id=None, part_ids=None, trigger_auto_download=None, from_user_id=None, cloud_storage_account_id=None, connection_id=None, email_attachment=None, email_link=None, email_subject=None, email_message=None, email_to=None, send_copy_to_me=None, format_name=None, notify_user=None, store_in_document=None, version_string=None, source_name=None, destination_name=None, flatten=None, include_export_ids=None, text_as_geometry=None, show_overridden_dimensions=None, current_sheet_only=None, image_width=None, image_height=None, color_method=None, splines_as_polylines=None, selectable_pdf_text=None, grouping=None, import_in_background=None, unit=None, split_assemblies_into_multiple_documents=None, flatten_assemblies=None, gety_axis_is_up=None, allow_faulty_parts=None, project_id=None, parent_id=None, foreign_id=None, upload_id=None, original_foreign_id=None, import_within_document=None, blob_element_id=None, blob_microversion_id=None, specify_units=None):  # noqa: E501
        """BTTranslateFormatParams - a model defined in OpenAPI"""  # noqa: E501

        self._link_document_id = None
        self._configuration = None
        self._element_id = None
        self._link_document_workspace_id = None
        self._cloud_object_id = None
        self._part_ids = None
        self._trigger_auto_download = None
        self._from_user_id = None
        self._cloud_storage_account_id = None
        self._connection_id = None
        self._email_attachment = None
        self._email_link = None
        self._email_subject = None
        self._email_message = None
        self._email_to = None
        self._send_copy_to_me = None
        self._format_name = None
        self._notify_user = None
        self._store_in_document = None
        self._version_string = None
        self._source_name = None
        self._destination_name = None
        self._flatten = None
        self._include_export_ids = None
        self._text_as_geometry = None
        self._show_overridden_dimensions = None
        self._current_sheet_only = None
        self._image_width = None
        self._image_height = None
        self._color_method = None
        self._splines_as_polylines = None
        self._selectable_pdf_text = None
        self._grouping = None
        self._import_in_background = None
        self._unit = None
        self._split_assemblies_into_multiple_documents = None
        self._flatten_assemblies = None
        self._gety_axis_is_up = None
        self._allow_faulty_parts = None
        self._project_id = None
        self._parent_id = None
        self._foreign_id = None
        self._upload_id = None
        self._original_foreign_id = None
        self._import_within_document = None
        self._blob_element_id = None
        self._blob_microversion_id = None
        self._specify_units = None
        self.discriminator = None

        if link_document_id is not None:
            self.link_document_id = link_document_id
        if configuration is not None:
            self.configuration = configuration
        if element_id is not None:
            self.element_id = element_id
        if link_document_workspace_id is not None:
            self.link_document_workspace_id = link_document_workspace_id
        if cloud_object_id is not None:
            self.cloud_object_id = cloud_object_id
        if part_ids is not None:
            self.part_ids = part_ids
        if trigger_auto_download is not None:
            self.trigger_auto_download = trigger_auto_download
        if from_user_id is not None:
            self.from_user_id = from_user_id
        if cloud_storage_account_id is not None:
            self.cloud_storage_account_id = cloud_storage_account_id
        if connection_id is not None:
            self.connection_id = connection_id
        if email_attachment is not None:
            self.email_attachment = email_attachment
        if email_link is not None:
            self.email_link = email_link
        if email_subject is not None:
            self.email_subject = email_subject
        if email_message is not None:
            self.email_message = email_message
        if email_to is not None:
            self.email_to = email_to
        if send_copy_to_me is not None:
            self.send_copy_to_me = send_copy_to_me
        if format_name is not None:
            self.format_name = format_name
        if notify_user is not None:
            self.notify_user = notify_user
        if store_in_document is not None:
            self.store_in_document = store_in_document
        if version_string is not None:
            self.version_string = version_string
        if source_name is not None:
            self.source_name = source_name
        if destination_name is not None:
            self.destination_name = destination_name
        if flatten is not None:
            self.flatten = flatten
        if include_export_ids is not None:
            self.include_export_ids = include_export_ids
        if text_as_geometry is not None:
            self.text_as_geometry = text_as_geometry
        if show_overridden_dimensions is not None:
            self.show_overridden_dimensions = show_overridden_dimensions
        if current_sheet_only is not None:
            self.current_sheet_only = current_sheet_only
        if image_width is not None:
            self.image_width = image_width
        if image_height is not None:
            self.image_height = image_height
        if color_method is not None:
            self.color_method = color_method
        if splines_as_polylines is not None:
            self.splines_as_polylines = splines_as_polylines
        if selectable_pdf_text is not None:
            self.selectable_pdf_text = selectable_pdf_text
        if grouping is not None:
            self.grouping = grouping
        if import_in_background is not None:
            self.import_in_background = import_in_background
        if unit is not None:
            self.unit = unit
        if split_assemblies_into_multiple_documents is not None:
            self.split_assemblies_into_multiple_documents = split_assemblies_into_multiple_documents
        if flatten_assemblies is not None:
            self.flatten_assemblies = flatten_assemblies
        if gety_axis_is_up is not None:
            self.gety_axis_is_up = gety_axis_is_up
        if allow_faulty_parts is not None:
            self.allow_faulty_parts = allow_faulty_parts
        if project_id is not None:
            self.project_id = project_id
        if parent_id is not None:
            self.parent_id = parent_id
        if foreign_id is not None:
            self.foreign_id = foreign_id
        if upload_id is not None:
            self.upload_id = upload_id
        if original_foreign_id is not None:
            self.original_foreign_id = original_foreign_id
        if import_within_document is not None:
            self.import_within_document = import_within_document
        if blob_element_id is not None:
            self.blob_element_id = blob_element_id
        if blob_microversion_id is not None:
            self.blob_microversion_id = blob_microversion_id
        if specify_units is not None:
            self.specify_units = specify_units

    @property
    def link_document_id(self):
        """Gets the link_document_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The link_document_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._link_document_id

    @link_document_id.setter
    def link_document_id(self, link_document_id):
        """Sets the link_document_id of this BTTranslateFormatParams.


        :param link_document_id: The link_document_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._link_document_id = link_document_id

    @property
    def configuration(self):
        """Gets the configuration of this BTTranslateFormatParams.  # noqa: E501


        :return: The configuration of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTTranslateFormatParams.


        :param configuration: The configuration of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def element_id(self):
        """Gets the element_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The element_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTTranslateFormatParams.


        :param element_id: The element_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def link_document_workspace_id(self):
        """Gets the link_document_workspace_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The link_document_workspace_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._link_document_workspace_id

    @link_document_workspace_id.setter
    def link_document_workspace_id(self, link_document_workspace_id):
        """Sets the link_document_workspace_id of this BTTranslateFormatParams.


        :param link_document_workspace_id: The link_document_workspace_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._link_document_workspace_id = link_document_workspace_id

    @property
    def cloud_object_id(self):
        """Gets the cloud_object_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The cloud_object_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_object_id

    @cloud_object_id.setter
    def cloud_object_id(self, cloud_object_id):
        """Sets the cloud_object_id of this BTTranslateFormatParams.


        :param cloud_object_id: The cloud_object_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._cloud_object_id = cloud_object_id

    @property
    def part_ids(self):
        """Gets the part_ids of this BTTranslateFormatParams.  # noqa: E501


        :return: The part_ids of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._part_ids

    @part_ids.setter
    def part_ids(self, part_ids):
        """Sets the part_ids of this BTTranslateFormatParams.


        :param part_ids: The part_ids of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._part_ids = part_ids

    @property
    def trigger_auto_download(self):
        """Gets the trigger_auto_download of this BTTranslateFormatParams.  # noqa: E501


        :return: The trigger_auto_download of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._trigger_auto_download

    @trigger_auto_download.setter
    def trigger_auto_download(self, trigger_auto_download):
        """Sets the trigger_auto_download of this BTTranslateFormatParams.


        :param trigger_auto_download: The trigger_auto_download of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._trigger_auto_download = trigger_auto_download

    @property
    def from_user_id(self):
        """Gets the from_user_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The from_user_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._from_user_id

    @from_user_id.setter
    def from_user_id(self, from_user_id):
        """Sets the from_user_id of this BTTranslateFormatParams.


        :param from_user_id: The from_user_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._from_user_id = from_user_id

    @property
    def cloud_storage_account_id(self):
        """Gets the cloud_storage_account_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The cloud_storage_account_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id

    @cloud_storage_account_id.setter
    def cloud_storage_account_id(self, cloud_storage_account_id):
        """Sets the cloud_storage_account_id of this BTTranslateFormatParams.


        :param cloud_storage_account_id: The cloud_storage_account_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id = cloud_storage_account_id

    @property
    def connection_id(self):
        """Gets the connection_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The connection_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this BTTranslateFormatParams.


        :param connection_id: The connection_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._connection_id = connection_id

    @property
    def email_attachment(self):
        """Gets the email_attachment of this BTTranslateFormatParams.  # noqa: E501


        :return: The email_attachment of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._email_attachment

    @email_attachment.setter
    def email_attachment(self, email_attachment):
        """Sets the email_attachment of this BTTranslateFormatParams.


        :param email_attachment: The email_attachment of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._email_attachment = email_attachment

    @property
    def email_link(self):
        """Gets the email_link of this BTTranslateFormatParams.  # noqa: E501


        :return: The email_link of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._email_link

    @email_link.setter
    def email_link(self, email_link):
        """Sets the email_link of this BTTranslateFormatParams.


        :param email_link: The email_link of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._email_link = email_link

    @property
    def email_subject(self):
        """Gets the email_subject of this BTTranslateFormatParams.  # noqa: E501


        :return: The email_subject of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """Sets the email_subject of this BTTranslateFormatParams.


        :param email_subject: The email_subject of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._email_subject = email_subject

    @property
    def email_message(self):
        """Gets the email_message of this BTTranslateFormatParams.  # noqa: E501


        :return: The email_message of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._email_message

    @email_message.setter
    def email_message(self, email_message):
        """Sets the email_message of this BTTranslateFormatParams.


        :param email_message: The email_message of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._email_message = email_message

    @property
    def email_to(self):
        """Gets the email_to of this BTTranslateFormatParams.  # noqa: E501


        :return: The email_to of this BTTranslateFormatParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_to

    @email_to.setter
    def email_to(self, email_to):
        """Sets the email_to of this BTTranslateFormatParams.


        :param email_to: The email_to of this BTTranslateFormatParams.  # noqa: E501
        :type: list[str]
        """

        self._email_to = email_to

    @property
    def send_copy_to_me(self):
        """Gets the send_copy_to_me of this BTTranslateFormatParams.  # noqa: E501


        :return: The send_copy_to_me of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._send_copy_to_me

    @send_copy_to_me.setter
    def send_copy_to_me(self, send_copy_to_me):
        """Sets the send_copy_to_me of this BTTranslateFormatParams.


        :param send_copy_to_me: The send_copy_to_me of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._send_copy_to_me = send_copy_to_me

    @property
    def format_name(self):
        """Gets the format_name of this BTTranslateFormatParams.  # noqa: E501


        :return: The format_name of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._format_name

    @format_name.setter
    def format_name(self, format_name):
        """Sets the format_name of this BTTranslateFormatParams.


        :param format_name: The format_name of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._format_name = format_name

    @property
    def notify_user(self):
        """Gets the notify_user of this BTTranslateFormatParams.  # noqa: E501


        :return: The notify_user of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._notify_user

    @notify_user.setter
    def notify_user(self, notify_user):
        """Sets the notify_user of this BTTranslateFormatParams.


        :param notify_user: The notify_user of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._notify_user = notify_user

    @property
    def store_in_document(self):
        """Gets the store_in_document of this BTTranslateFormatParams.  # noqa: E501


        :return: The store_in_document of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._store_in_document

    @store_in_document.setter
    def store_in_document(self, store_in_document):
        """Sets the store_in_document of this BTTranslateFormatParams.


        :param store_in_document: The store_in_document of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._store_in_document = store_in_document

    @property
    def version_string(self):
        """Gets the version_string of this BTTranslateFormatParams.  # noqa: E501


        :return: The version_string of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._version_string

    @version_string.setter
    def version_string(self, version_string):
        """Sets the version_string of this BTTranslateFormatParams.


        :param version_string: The version_string of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._version_string = version_string

    @property
    def source_name(self):
        """Gets the source_name of this BTTranslateFormatParams.  # noqa: E501


        :return: The source_name of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this BTTranslateFormatParams.


        :param source_name: The source_name of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._source_name = source_name

    @property
    def destination_name(self):
        """Gets the destination_name of this BTTranslateFormatParams.  # noqa: E501


        :return: The destination_name of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._destination_name

    @destination_name.setter
    def destination_name(self, destination_name):
        """Sets the destination_name of this BTTranslateFormatParams.


        :param destination_name: The destination_name of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._destination_name = destination_name

    @property
    def flatten(self):
        """Gets the flatten of this BTTranslateFormatParams.  # noqa: E501


        :return: The flatten of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._flatten

    @flatten.setter
    def flatten(self, flatten):
        """Sets the flatten of this BTTranslateFormatParams.


        :param flatten: The flatten of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._flatten = flatten

    @property
    def include_export_ids(self):
        """Gets the include_export_ids of this BTTranslateFormatParams.  # noqa: E501


        :return: The include_export_ids of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_export_ids

    @include_export_ids.setter
    def include_export_ids(self, include_export_ids):
        """Sets the include_export_ids of this BTTranslateFormatParams.


        :param include_export_ids: The include_export_ids of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._include_export_ids = include_export_ids

    @property
    def text_as_geometry(self):
        """Gets the text_as_geometry of this BTTranslateFormatParams.  # noqa: E501


        :return: The text_as_geometry of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._text_as_geometry

    @text_as_geometry.setter
    def text_as_geometry(self, text_as_geometry):
        """Sets the text_as_geometry of this BTTranslateFormatParams.


        :param text_as_geometry: The text_as_geometry of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._text_as_geometry = text_as_geometry

    @property
    def show_overridden_dimensions(self):
        """Gets the show_overridden_dimensions of this BTTranslateFormatParams.  # noqa: E501


        :return: The show_overridden_dimensions of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_overridden_dimensions

    @show_overridden_dimensions.setter
    def show_overridden_dimensions(self, show_overridden_dimensions):
        """Sets the show_overridden_dimensions of this BTTranslateFormatParams.


        :param show_overridden_dimensions: The show_overridden_dimensions of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._show_overridden_dimensions = show_overridden_dimensions

    @property
    def current_sheet_only(self):
        """Gets the current_sheet_only of this BTTranslateFormatParams.  # noqa: E501


        :return: The current_sheet_only of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._current_sheet_only

    @current_sheet_only.setter
    def current_sheet_only(self, current_sheet_only):
        """Sets the current_sheet_only of this BTTranslateFormatParams.


        :param current_sheet_only: The current_sheet_only of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._current_sheet_only = current_sheet_only

    @property
    def image_width(self):
        """Gets the image_width of this BTTranslateFormatParams.  # noqa: E501


        :return: The image_width of this BTTranslateFormatParams.  # noqa: E501
        :rtype: int
        """
        return self._image_width

    @image_width.setter
    def image_width(self, image_width):
        """Sets the image_width of this BTTranslateFormatParams.


        :param image_width: The image_width of this BTTranslateFormatParams.  # noqa: E501
        :type: int
        """

        self._image_width = image_width

    @property
    def image_height(self):
        """Gets the image_height of this BTTranslateFormatParams.  # noqa: E501


        :return: The image_height of this BTTranslateFormatParams.  # noqa: E501
        :rtype: int
        """
        return self._image_height

    @image_height.setter
    def image_height(self, image_height):
        """Sets the image_height of this BTTranslateFormatParams.


        :param image_height: The image_height of this BTTranslateFormatParams.  # noqa: E501
        :type: int
        """

        self._image_height = image_height

    @property
    def color_method(self):
        """Gets the color_method of this BTTranslateFormatParams.  # noqa: E501


        :return: The color_method of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._color_method

    @color_method.setter
    def color_method(self, color_method):
        """Sets the color_method of this BTTranslateFormatParams.


        :param color_method: The color_method of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._color_method = color_method

    @property
    def splines_as_polylines(self):
        """Gets the splines_as_polylines of this BTTranslateFormatParams.  # noqa: E501


        :return: The splines_as_polylines of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._splines_as_polylines

    @splines_as_polylines.setter
    def splines_as_polylines(self, splines_as_polylines):
        """Sets the splines_as_polylines of this BTTranslateFormatParams.


        :param splines_as_polylines: The splines_as_polylines of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._splines_as_polylines = splines_as_polylines

    @property
    def selectable_pdf_text(self):
        """Gets the selectable_pdf_text of this BTTranslateFormatParams.  # noqa: E501


        :return: The selectable_pdf_text of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._selectable_pdf_text

    @selectable_pdf_text.setter
    def selectable_pdf_text(self, selectable_pdf_text):
        """Sets the selectable_pdf_text of this BTTranslateFormatParams.


        :param selectable_pdf_text: The selectable_pdf_text of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._selectable_pdf_text = selectable_pdf_text

    @property
    def grouping(self):
        """Gets the grouping of this BTTranslateFormatParams.  # noqa: E501


        :return: The grouping of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._grouping

    @grouping.setter
    def grouping(self, grouping):
        """Sets the grouping of this BTTranslateFormatParams.


        :param grouping: The grouping of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._grouping = grouping

    @property
    def import_in_background(self):
        """Gets the import_in_background of this BTTranslateFormatParams.  # noqa: E501


        :return: The import_in_background of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._import_in_background

    @import_in_background.setter
    def import_in_background(self, import_in_background):
        """Sets the import_in_background of this BTTranslateFormatParams.


        :param import_in_background: The import_in_background of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._import_in_background = import_in_background

    @property
    def unit(self):
        """Gets the unit of this BTTranslateFormatParams.  # noqa: E501


        :return: The unit of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this BTTranslateFormatParams.


        :param unit: The unit of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def split_assemblies_into_multiple_documents(self):
        """Gets the split_assemblies_into_multiple_documents of this BTTranslateFormatParams.  # noqa: E501


        :return: The split_assemblies_into_multiple_documents of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._split_assemblies_into_multiple_documents

    @split_assemblies_into_multiple_documents.setter
    def split_assemblies_into_multiple_documents(self, split_assemblies_into_multiple_documents):
        """Sets the split_assemblies_into_multiple_documents of this BTTranslateFormatParams.


        :param split_assemblies_into_multiple_documents: The split_assemblies_into_multiple_documents of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._split_assemblies_into_multiple_documents = split_assemblies_into_multiple_documents

    @property
    def flatten_assemblies(self):
        """Gets the flatten_assemblies of this BTTranslateFormatParams.  # noqa: E501


        :return: The flatten_assemblies of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._flatten_assemblies

    @flatten_assemblies.setter
    def flatten_assemblies(self, flatten_assemblies):
        """Sets the flatten_assemblies of this BTTranslateFormatParams.


        :param flatten_assemblies: The flatten_assemblies of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._flatten_assemblies = flatten_assemblies

    @property
    def gety_axis_is_up(self):
        """Gets the gety_axis_is_up of this BTTranslateFormatParams.  # noqa: E501


        :return: The gety_axis_is_up of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._gety_axis_is_up

    @gety_axis_is_up.setter
    def gety_axis_is_up(self, gety_axis_is_up):
        """Sets the gety_axis_is_up of this BTTranslateFormatParams.


        :param gety_axis_is_up: The gety_axis_is_up of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._gety_axis_is_up = gety_axis_is_up

    @property
    def allow_faulty_parts(self):
        """Gets the allow_faulty_parts of this BTTranslateFormatParams.  # noqa: E501


        :return: The allow_faulty_parts of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._allow_faulty_parts

    @allow_faulty_parts.setter
    def allow_faulty_parts(self, allow_faulty_parts):
        """Sets the allow_faulty_parts of this BTTranslateFormatParams.


        :param allow_faulty_parts: The allow_faulty_parts of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._allow_faulty_parts = allow_faulty_parts

    @property
    def project_id(self):
        """Gets the project_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The project_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTTranslateFormatParams.


        :param project_id: The project_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def parent_id(self):
        """Gets the parent_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The parent_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTTranslateFormatParams.


        :param parent_id: The parent_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def foreign_id(self):
        """Gets the foreign_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The foreign_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._foreign_id

    @foreign_id.setter
    def foreign_id(self, foreign_id):
        """Sets the foreign_id of this BTTranslateFormatParams.


        :param foreign_id: The foreign_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._foreign_id = foreign_id

    @property
    def upload_id(self):
        """Gets the upload_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The upload_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this BTTranslateFormatParams.


        :param upload_id: The upload_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._upload_id = upload_id

    @property
    def original_foreign_id(self):
        """Gets the original_foreign_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The original_foreign_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._original_foreign_id

    @original_foreign_id.setter
    def original_foreign_id(self, original_foreign_id):
        """Sets the original_foreign_id of this BTTranslateFormatParams.


        :param original_foreign_id: The original_foreign_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._original_foreign_id = original_foreign_id

    @property
    def import_within_document(self):
        """Gets the import_within_document of this BTTranslateFormatParams.  # noqa: E501


        :return: The import_within_document of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._import_within_document

    @import_within_document.setter
    def import_within_document(self, import_within_document):
        """Sets the import_within_document of this BTTranslateFormatParams.


        :param import_within_document: The import_within_document of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._import_within_document = import_within_document

    @property
    def blob_element_id(self):
        """Gets the blob_element_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The blob_element_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._blob_element_id

    @blob_element_id.setter
    def blob_element_id(self, blob_element_id):
        """Sets the blob_element_id of this BTTranslateFormatParams.


        :param blob_element_id: The blob_element_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._blob_element_id = blob_element_id

    @property
    def blob_microversion_id(self):
        """Gets the blob_microversion_id of this BTTranslateFormatParams.  # noqa: E501


        :return: The blob_microversion_id of this BTTranslateFormatParams.  # noqa: E501
        :rtype: str
        """
        return self._blob_microversion_id

    @blob_microversion_id.setter
    def blob_microversion_id(self, blob_microversion_id):
        """Sets the blob_microversion_id of this BTTranslateFormatParams.


        :param blob_microversion_id: The blob_microversion_id of this BTTranslateFormatParams.  # noqa: E501
        :type: str
        """

        self._blob_microversion_id = blob_microversion_id

    @property
    def specify_units(self):
        """Gets the specify_units of this BTTranslateFormatParams.  # noqa: E501


        :return: The specify_units of this BTTranslateFormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._specify_units

    @specify_units.setter
    def specify_units(self, specify_units):
        """Sets the specify_units of this BTTranslateFormatParams.


        :param specify_units: The specify_units of this BTTranslateFormatParams.  # noqa: E501
        :type: bool
        """

        self._specify_units = specify_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTTranslateFormatParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import print_function
import pint
from onshape_client.units import u

ureg = pint.UnitRegistry()

def test_configuration_update(configurable_cubes):

    assert configurable_cubes[2]._get_default_configuration_map() == {'size': 1.0 * u.inch, 'Configuration': 'Default'}
    configurable_cubes[2].update_current_configuration({"size": 20*ureg.m})
    assert configurable_cubes[2].get_url_with_configuration() == 'https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/ca51b7554314d6aab254d2e6/e/69c9eedda86512966b20bc90?configuration=List_UKkGODiz574chc%3DDefault%3Bsize%3D20+meter'
    configurable_cubes[2].update_current_configuration({'size': 40 * u.inch, 'Configuration': 'chamfered'})
    assert configurable_cubes[2].get_url_with_configuration() == 'https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/ca51b7554314d6aab254d2e6/e/69c9eedda86512966b20bc90?configuration=List_UKkGODiz574chc%3Dchamfered%3Bsize%3D40+inch'
    configurable_cubes[3].update_current_configuration({'size': 10 * u.inch, 'edge_configuration': 'chamfered', 'show_cube': False})
    assert configurable_cubes[3].get_url_with_configuration() == 'https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/aaa25d18038e06f0b2964e2d/e/69c9eedda86512966b20bc90?configuration=List_UKkGODiz574chc%3Dchamfered%3Bshow_cube%3DFalse%3Bsize%3D10+inch'


from onshape_client.models.bt_id_translation_params import BTIdTranslationParams
from onshape_client.models.bt_id_translation_info import BTIdTranslationInfo

def test_translate_ids(configurable_cubes, client):
    sketch_id = "JCF"
    params = BTIdTranslationParams(ids=[sketch_id], source_document_microversion="99097c624be5cd434b03f906")
    cube = configurable_cubes[1]
    result = client.part_studios_api.translate_ids1(cube.did, cube.wvm, cube.wvmid, cube.eid, params)
    assert result.ids[0].source == sketch_id
    assert result.ids[0].target[0] == sketch_id



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAPIApplicationParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hidden_from_plus_menu_': 'bool',
        'name': 'str',
        'state': 'int',
        'description': 'str',
        'primary_format': 'str',
        'internal_grant_on_demand': 'bool',
        'client_id': 'str',
        'scope_names': 'list[str]',
        'developer_email': 'str',
        'base_href': 'str',
        'supports_collaboration': 'bool',
        'developer_id': 'str',
        'redirect_ur_ls': 'list[str]',
        'ui_spec': 'str',
        'supports_merge': 'bool',
        'admin_team_id': 'str',
        'hidden_from_plus_menu': 'bool',
        'store_entry_is_public': 'bool'
    }

    attribute_map = {
        'hidden_from_plus_menu_': 'hiddenFromPlusMenu_',
        'name': 'name',
        'state': 'state',
        'description': 'description',
        'primary_format': 'primaryFormat',
        'internal_grant_on_demand': 'internalGrantOnDemand',
        'client_id': 'clientId',
        'scope_names': 'scopeNames',
        'developer_email': 'developerEmail',
        'base_href': 'baseHref',
        'supports_collaboration': 'supportsCollaboration',
        'developer_id': 'developerId',
        'redirect_ur_ls': 'redirectURLs',
        'ui_spec': 'uiSpec',
        'supports_merge': 'supportsMerge',
        'admin_team_id': 'adminTeamId',
        'hidden_from_plus_menu': 'hiddenFromPlusMenu',
        'store_entry_is_public': 'storeEntryIsPublic'
    }

    def __init__(self, hidden_from_plus_menu_=None, name=None, state=None, description=None, primary_format=None, internal_grant_on_demand=None, client_id=None, scope_names=None, developer_email=None, base_href=None, supports_collaboration=None, developer_id=None, redirect_ur_ls=None, ui_spec=None, supports_merge=None, admin_team_id=None, hidden_from_plus_menu=None, store_entry_is_public=None):  # noqa: E501
        """BTAPIApplicationParams - a model defined in OpenAPI"""  # noqa: E501

        self._hidden_from_plus_menu_ = None
        self._name = None
        self._state = None
        self._description = None
        self._primary_format = None
        self._internal_grant_on_demand = None
        self._client_id = None
        self._scope_names = None
        self._developer_email = None
        self._base_href = None
        self._supports_collaboration = None
        self._developer_id = None
        self._redirect_ur_ls = None
        self._ui_spec = None
        self._supports_merge = None
        self._admin_team_id = None
        self._hidden_from_plus_menu = None
        self._store_entry_is_public = None
        self.discriminator = None

        if hidden_from_plus_menu_ is not None:
            self.hidden_from_plus_menu_ = hidden_from_plus_menu_
        if name is not None:
            self.name = name
        if state is not None:
            self.state = state
        if description is not None:
            self.description = description
        if primary_format is not None:
            self.primary_format = primary_format
        if internal_grant_on_demand is not None:
            self.internal_grant_on_demand = internal_grant_on_demand
        if client_id is not None:
            self.client_id = client_id
        if scope_names is not None:
            self.scope_names = scope_names
        if developer_email is not None:
            self.developer_email = developer_email
        if base_href is not None:
            self.base_href = base_href
        if supports_collaboration is not None:
            self.supports_collaboration = supports_collaboration
        if developer_id is not None:
            self.developer_id = developer_id
        if redirect_ur_ls is not None:
            self.redirect_ur_ls = redirect_ur_ls
        if ui_spec is not None:
            self.ui_spec = ui_spec
        if supports_merge is not None:
            self.supports_merge = supports_merge
        if admin_team_id is not None:
            self.admin_team_id = admin_team_id
        if hidden_from_plus_menu is not None:
            self.hidden_from_plus_menu = hidden_from_plus_menu
        if store_entry_is_public is not None:
            self.store_entry_is_public = store_entry_is_public

    @property
    def hidden_from_plus_menu_(self):
        """Gets the hidden_from_plus_menu_ of this BTAPIApplicationParams.  # noqa: E501


        :return: The hidden_from_plus_menu_ of this BTAPIApplicationParams.  # noqa: E501
        :rtype: bool
        """
        return self._hidden_from_plus_menu_

    @hidden_from_plus_menu_.setter
    def hidden_from_plus_menu_(self, hidden_from_plus_menu_):
        """Sets the hidden_from_plus_menu_ of this BTAPIApplicationParams.


        :param hidden_from_plus_menu_: The hidden_from_plus_menu_ of this BTAPIApplicationParams.  # noqa: E501
        :type: bool
        """

        self._hidden_from_plus_menu_ = hidden_from_plus_menu_

    @property
    def name(self):
        """Gets the name of this BTAPIApplicationParams.  # noqa: E501


        :return: The name of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTAPIApplicationParams.


        :param name: The name of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def state(self):
        """Gets the state of this BTAPIApplicationParams.  # noqa: E501


        :return: The state of this BTAPIApplicationParams.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTAPIApplicationParams.


        :param state: The state of this BTAPIApplicationParams.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def description(self):
        """Gets the description of this BTAPIApplicationParams.  # noqa: E501


        :return: The description of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTAPIApplicationParams.


        :param description: The description of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def primary_format(self):
        """Gets the primary_format of this BTAPIApplicationParams.  # noqa: E501


        :return: The primary_format of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._primary_format

    @primary_format.setter
    def primary_format(self, primary_format):
        """Sets the primary_format of this BTAPIApplicationParams.


        :param primary_format: The primary_format of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._primary_format = primary_format

    @property
    def internal_grant_on_demand(self):
        """Gets the internal_grant_on_demand of this BTAPIApplicationParams.  # noqa: E501


        :return: The internal_grant_on_demand of this BTAPIApplicationParams.  # noqa: E501
        :rtype: bool
        """
        return self._internal_grant_on_demand

    @internal_grant_on_demand.setter
    def internal_grant_on_demand(self, internal_grant_on_demand):
        """Sets the internal_grant_on_demand of this BTAPIApplicationParams.


        :param internal_grant_on_demand: The internal_grant_on_demand of this BTAPIApplicationParams.  # noqa: E501
        :type: bool
        """

        self._internal_grant_on_demand = internal_grant_on_demand

    @property
    def client_id(self):
        """Gets the client_id of this BTAPIApplicationParams.  # noqa: E501


        :return: The client_id of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BTAPIApplicationParams.


        :param client_id: The client_id of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def scope_names(self):
        """Gets the scope_names of this BTAPIApplicationParams.  # noqa: E501


        :return: The scope_names of this BTAPIApplicationParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._scope_names

    @scope_names.setter
    def scope_names(self, scope_names):
        """Sets the scope_names of this BTAPIApplicationParams.


        :param scope_names: The scope_names of this BTAPIApplicationParams.  # noqa: E501
        :type: list[str]
        """

        self._scope_names = scope_names

    @property
    def developer_email(self):
        """Gets the developer_email of this BTAPIApplicationParams.  # noqa: E501


        :return: The developer_email of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._developer_email

    @developer_email.setter
    def developer_email(self, developer_email):
        """Sets the developer_email of this BTAPIApplicationParams.


        :param developer_email: The developer_email of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._developer_email = developer_email

    @property
    def base_href(self):
        """Gets the base_href of this BTAPIApplicationParams.  # noqa: E501


        :return: The base_href of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._base_href

    @base_href.setter
    def base_href(self, base_href):
        """Sets the base_href of this BTAPIApplicationParams.


        :param base_href: The base_href of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._base_href = base_href

    @property
    def supports_collaboration(self):
        """Gets the supports_collaboration of this BTAPIApplicationParams.  # noqa: E501


        :return: The supports_collaboration of this BTAPIApplicationParams.  # noqa: E501
        :rtype: bool
        """
        return self._supports_collaboration

    @supports_collaboration.setter
    def supports_collaboration(self, supports_collaboration):
        """Sets the supports_collaboration of this BTAPIApplicationParams.


        :param supports_collaboration: The supports_collaboration of this BTAPIApplicationParams.  # noqa: E501
        :type: bool
        """

        self._supports_collaboration = supports_collaboration

    @property
    def developer_id(self):
        """Gets the developer_id of this BTAPIApplicationParams.  # noqa: E501


        :return: The developer_id of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._developer_id

    @developer_id.setter
    def developer_id(self, developer_id):
        """Sets the developer_id of this BTAPIApplicationParams.


        :param developer_id: The developer_id of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._developer_id = developer_id

    @property
    def redirect_ur_ls(self):
        """Gets the redirect_ur_ls of this BTAPIApplicationParams.  # noqa: E501


        :return: The redirect_ur_ls of this BTAPIApplicationParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._redirect_ur_ls

    @redirect_ur_ls.setter
    def redirect_ur_ls(self, redirect_ur_ls):
        """Sets the redirect_ur_ls of this BTAPIApplicationParams.


        :param redirect_ur_ls: The redirect_ur_ls of this BTAPIApplicationParams.  # noqa: E501
        :type: list[str]
        """

        self._redirect_ur_ls = redirect_ur_ls

    @property
    def ui_spec(self):
        """Gets the ui_spec of this BTAPIApplicationParams.  # noqa: E501


        :return: The ui_spec of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._ui_spec

    @ui_spec.setter
    def ui_spec(self, ui_spec):
        """Sets the ui_spec of this BTAPIApplicationParams.


        :param ui_spec: The ui_spec of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._ui_spec = ui_spec

    @property
    def supports_merge(self):
        """Gets the supports_merge of this BTAPIApplicationParams.  # noqa: E501


        :return: The supports_merge of this BTAPIApplicationParams.  # noqa: E501
        :rtype: bool
        """
        return self._supports_merge

    @supports_merge.setter
    def supports_merge(self, supports_merge):
        """Sets the supports_merge of this BTAPIApplicationParams.


        :param supports_merge: The supports_merge of this BTAPIApplicationParams.  # noqa: E501
        :type: bool
        """

        self._supports_merge = supports_merge

    @property
    def admin_team_id(self):
        """Gets the admin_team_id of this BTAPIApplicationParams.  # noqa: E501


        :return: The admin_team_id of this BTAPIApplicationParams.  # noqa: E501
        :rtype: str
        """
        return self._admin_team_id

    @admin_team_id.setter
    def admin_team_id(self, admin_team_id):
        """Sets the admin_team_id of this BTAPIApplicationParams.


        :param admin_team_id: The admin_team_id of this BTAPIApplicationParams.  # noqa: E501
        :type: str
        """

        self._admin_team_id = admin_team_id

    @property
    def hidden_from_plus_menu(self):
        """Gets the hidden_from_plus_menu of this BTAPIApplicationParams.  # noqa: E501


        :return: The hidden_from_plus_menu of this BTAPIApplicationParams.  # noqa: E501
        :rtype: bool
        """
        return self._hidden_from_plus_menu

    @hidden_from_plus_menu.setter
    def hidden_from_plus_menu(self, hidden_from_plus_menu):
        """Sets the hidden_from_plus_menu of this BTAPIApplicationParams.


        :param hidden_from_plus_menu: The hidden_from_plus_menu of this BTAPIApplicationParams.  # noqa: E501
        :type: bool
        """

        self._hidden_from_plus_menu = hidden_from_plus_menu

    @property
    def store_entry_is_public(self):
        """Gets the store_entry_is_public of this BTAPIApplicationParams.  # noqa: E501


        :return: The store_entry_is_public of this BTAPIApplicationParams.  # noqa: E501
        :rtype: bool
        """
        return self._store_entry_is_public

    @store_entry_is_public.setter
    def store_entry_is_public(self, store_entry_is_public):
        """Sets the store_entry_is_public of this BTAPIApplicationParams.


        :param store_entry_is_public: The store_entry_is_public of this BTAPIApplicationParams.  # noqa: E501
        :type: bool
        """

        self._store_entry_is_public = store_entry_is_public

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAPIApplicationParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMetadataPropertyInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'default_value': 'object',
        'initial_value': 'object',
        'dirty': 'bool',
        'editable': 'bool',
        'property_id': 'str',
        'value_type': 'str',
        'required': 'bool',
        'schema_id': 'str',
        'enum_values': 'list[BTMetadataEnumValueInfo]',
        'editable_in_ui': 'bool',
        'validator': 'BTMetadataPropertyValidatorInfo',
        'property_source': 'int',
        'ui_hints': 'BTMetadataPropertyUiHintsInfo'
    }

    attribute_map = {
        'name': 'name',
        'default_value': 'defaultValue',
        'initial_value': 'initialValue',
        'dirty': 'dirty',
        'editable': 'editable',
        'property_id': 'propertyId',
        'value_type': 'valueType',
        'required': 'required',
        'schema_id': 'schemaId',
        'enum_values': 'enumValues',
        'editable_in_ui': 'editableInUi',
        'validator': 'validator',
        'property_source': 'propertySource',
        'ui_hints': 'uiHints'
    }

    def __init__(self, name=None, default_value=None, initial_value=None, dirty=None, editable=None, property_id=None, value_type=None, required=None, schema_id=None, enum_values=None, editable_in_ui=None, validator=None, property_source=None, ui_hints=None):  # noqa: E501
        """BTMetadataPropertyInfo - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._default_value = None
        self._initial_value = None
        self._dirty = None
        self._editable = None
        self._property_id = None
        self._value_type = None
        self._required = None
        self._schema_id = None
        self._enum_values = None
        self._editable_in_ui = None
        self._validator = None
        self._property_source = None
        self._ui_hints = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if default_value is not None:
            self.default_value = default_value
        if initial_value is not None:
            self.initial_value = initial_value
        if dirty is not None:
            self.dirty = dirty
        if editable is not None:
            self.editable = editable
        if property_id is not None:
            self.property_id = property_id
        if value_type is not None:
            self.value_type = value_type
        if required is not None:
            self.required = required
        if schema_id is not None:
            self.schema_id = schema_id
        if enum_values is not None:
            self.enum_values = enum_values
        if editable_in_ui is not None:
            self.editable_in_ui = editable_in_ui
        if validator is not None:
            self.validator = validator
        if property_source is not None:
            self.property_source = property_source
        if ui_hints is not None:
            self.ui_hints = ui_hints

    @property
    def name(self):
        """Gets the name of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The name of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTMetadataPropertyInfo.


        :param name: The name of this BTMetadataPropertyInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def default_value(self):
        """Gets the default_value of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The default_value of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this BTMetadataPropertyInfo.


        :param default_value: The default_value of this BTMetadataPropertyInfo.  # noqa: E501
        :type: object
        """

        self._default_value = default_value

    @property
    def initial_value(self):
        """Gets the initial_value of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The initial_value of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: object
        """
        return self._initial_value

    @initial_value.setter
    def initial_value(self, initial_value):
        """Sets the initial_value of this BTMetadataPropertyInfo.


        :param initial_value: The initial_value of this BTMetadataPropertyInfo.  # noqa: E501
        :type: object
        """

        self._initial_value = initial_value

    @property
    def dirty(self):
        """Gets the dirty of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The dirty of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._dirty

    @dirty.setter
    def dirty(self, dirty):
        """Sets the dirty of this BTMetadataPropertyInfo.


        :param dirty: The dirty of this BTMetadataPropertyInfo.  # noqa: E501
        :type: bool
        """

        self._dirty = dirty

    @property
    def editable(self):
        """Gets the editable of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The editable of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._editable

    @editable.setter
    def editable(self, editable):
        """Sets the editable of this BTMetadataPropertyInfo.


        :param editable: The editable of this BTMetadataPropertyInfo.  # noqa: E501
        :type: bool
        """

        self._editable = editable

    @property
    def property_id(self):
        """Gets the property_id of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The property_id of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: str
        """
        return self._property_id

    @property_id.setter
    def property_id(self, property_id):
        """Sets the property_id of this BTMetadataPropertyInfo.


        :param property_id: The property_id of this BTMetadataPropertyInfo.  # noqa: E501
        :type: str
        """

        self._property_id = property_id

    @property
    def value_type(self):
        """Gets the value_type of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The value_type of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this BTMetadataPropertyInfo.


        :param value_type: The value_type of this BTMetadataPropertyInfo.  # noqa: E501
        :type: str
        """

        self._value_type = value_type

    @property
    def required(self):
        """Gets the required of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The required of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this BTMetadataPropertyInfo.


        :param required: The required of this BTMetadataPropertyInfo.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def schema_id(self):
        """Gets the schema_id of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The schema_id of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: str
        """
        return self._schema_id

    @schema_id.setter
    def schema_id(self, schema_id):
        """Sets the schema_id of this BTMetadataPropertyInfo.


        :param schema_id: The schema_id of this BTMetadataPropertyInfo.  # noqa: E501
        :type: str
        """

        self._schema_id = schema_id

    @property
    def enum_values(self):
        """Gets the enum_values of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The enum_values of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: list[BTMetadataEnumValueInfo]
        """
        return self._enum_values

    @enum_values.setter
    def enum_values(self, enum_values):
        """Sets the enum_values of this BTMetadataPropertyInfo.


        :param enum_values: The enum_values of this BTMetadataPropertyInfo.  # noqa: E501
        :type: list[BTMetadataEnumValueInfo]
        """

        self._enum_values = enum_values

    @property
    def editable_in_ui(self):
        """Gets the editable_in_ui of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The editable_in_ui of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._editable_in_ui

    @editable_in_ui.setter
    def editable_in_ui(self, editable_in_ui):
        """Sets the editable_in_ui of this BTMetadataPropertyInfo.


        :param editable_in_ui: The editable_in_ui of this BTMetadataPropertyInfo.  # noqa: E501
        :type: bool
        """

        self._editable_in_ui = editable_in_ui

    @property
    def validator(self):
        """Gets the validator of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The validator of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: BTMetadataPropertyValidatorInfo
        """
        return self._validator

    @validator.setter
    def validator(self, validator):
        """Sets the validator of this BTMetadataPropertyInfo.


        :param validator: The validator of this BTMetadataPropertyInfo.  # noqa: E501
        :type: BTMetadataPropertyValidatorInfo
        """

        self._validator = validator

    @property
    def property_source(self):
        """Gets the property_source of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The property_source of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: int
        """
        return self._property_source

    @property_source.setter
    def property_source(self, property_source):
        """Sets the property_source of this BTMetadataPropertyInfo.


        :param property_source: The property_source of this BTMetadataPropertyInfo.  # noqa: E501
        :type: int
        """

        self._property_source = property_source

    @property
    def ui_hints(self):
        """Gets the ui_hints of this BTMetadataPropertyInfo.  # noqa: E501


        :return: The ui_hints of this BTMetadataPropertyInfo.  # noqa: E501
        :rtype: BTMetadataPropertyUiHintsInfo
        """
        return self._ui_hints

    @ui_hints.setter
    def ui_hints(self, ui_hints):
        """Sets the ui_hints of this BTMetadataPropertyInfo.


        :param ui_hints: The ui_hints of this BTMetadataPropertyInfo.  # noqa: E501
        :type: BTMetadataPropertyUiHintsInfo
        """

        self._ui_hints = ui_hints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMetadataPropertyInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
